@@ -198,7 +198,7 @@ class BaseRoute(BaseModel):
         return False
     
     @lazyproperty
-    def gql(self) -> Type[BaseGraphQLQuery]:
+    def gql(self) -> BaseGraphQLQuery:
         return BaseGraphQLQuery(
             resource_name = self.api_resource
         )
@@ -208,7 +208,7 @@ class BaseRoute(BaseModel):
         resource_id: str, 
         params: Optional[Dict[str, Any]] = None,
         **kwargs
-    ) -> Type[BaseResource]:
+    ) -> BaseResource:
         """
         GET a Single Resource
 
@@ -233,7 +233,7 @@ class BaseRoute(BaseModel):
         resource_id: str, 
         params: Optional[Dict[str, Any]] = None,
         **kwargs
-    )  -> Type[BaseResource]:
+    )  -> BaseResource:
         """
         GET a Single Resource
 
@@ -250,20 +250,21 @@ class BaseRoute(BaseModel):
             **kwargs
         )
         data = self.handle_response(api_response)
-        if data: data = data.json().get(self.root_name)
-        return self.prepare_response(data)
+        if data:
+            data = data.json().get(self.root_name)
+            return self.prepare_response(data)
 
     def find_all(
         self, 
         params: Optional[Dict[str, Any]] = None,
         **kwargs
-    ) -> Dict[str, Union[List[Type[BaseResource]], Dict[str, Any]]]:
+    ) -> Dict[str, Union[List[BaseResource], Dict[str, Any]]]:
         """
         GET all available objects of Resource
 
         :param params: Optional Query Parameters
         
-        :return: Dict[str, Union[List[Type[BaseResource]], Dict[str, Any]]]
+        :return: Dict[str, Union[List[BaseResource], Dict[str, Any]]]
         """
         api_response = self._send(
             method = 'GET',
@@ -281,13 +282,13 @@ class BaseRoute(BaseModel):
         self, 
         params: Optional[Dict[str, Any]] = None,
         **kwargs
-    ) -> Dict[str, Union[List[Type[BaseResource]], Dict[str, Any]]]:
+    ) -> Dict[str, Union[List[BaseResource], Dict[str, Any]]]:
         """
         GET all available objects of Resource
 
         :param params: Optional Query Parameters
 
-        :return: Dict[str, Union[List[Type[BaseResource]], Dict[str, Any]]]
+        :return: Dict[str, Union[List[BaseResource], Dict[str, Any]]]
         """
         api_response = await self._async_send(
             method = 'GET',
@@ -306,7 +307,7 @@ class BaseRoute(BaseModel):
         resource_id: str, 
         params: Optional[Dict[str, Any]] = None,
         **kwargs
-    ) -> Type[BaseResource]:
+    ) -> BaseResource:
         """
         GET a Single Resource
 
@@ -320,7 +321,7 @@ class BaseRoute(BaseModel):
         resource_id: str,
         params: Optional[Dict[str, Any]] = None,
         **kwargs
-    ) -> Type[BaseResource]:
+    ) -> BaseResource:
         """
         GET a Single Resource
 
@@ -333,13 +334,13 @@ class BaseRoute(BaseModel):
         self,
         params: Optional[Dict[str, Any]] = None,
         **kwargs
-    ) -> Dict[str, Union[List[Type[BaseResource]], Dict[str, Any]]]:
+    ) -> Dict[str, Union[List[BaseResource], Dict[str, Any]]]:
         """
         GET all available objects of Resource
 
         :param params: Optional Query Parameters
 
-        :return: Dict[str, Union[List[Type[BaseResource]], Dict[str, Any]]]
+        :return: Dict[str, Union[List[BaseResource], Dict[str, Any]]]
         """
         return self.find_all(params = params, **kwargs)
     
@@ -347,13 +348,13 @@ class BaseRoute(BaseModel):
         self,
         params: Optional[Dict[str, Any]] = None,
         **kwargs
-    ) -> Dict[str, Union[List[Type[BaseResource]], Dict[str, Any]]]:
+    ) -> Dict[str, Union[List[BaseResource], Dict[str, Any]]]:
         """
         GET all available objects of Resource
 
         :param params: Optional Query Parameters
         
-        :return: Dict[str, Union[List[Type[BaseResource]], Dict[str, Any]]]
+        :return: Dict[str, Union[List[BaseResource], Dict[str, Any]]]
         """
         return await self.async_find_all(params = params, **kwargs)    
 
@@ -404,7 +405,7 @@ class BaseRoute(BaseModel):
 
     def create(
         self, 
-        input_object: Optional[Type[BaseResource]] = None,
+        input_object: Optional[BaseResource] = None,
         **kwargs
     ):
         """
@@ -436,7 +437,7 @@ class BaseRoute(BaseModel):
     
     async def async_create(
         self, 
-        input_object: Optional[Type[BaseResource]] = None,
+        input_object: Optional[BaseResource] = None,
         **kwargs
     ):
         """
@@ -468,7 +469,7 @@ class BaseRoute(BaseModel):
     
     def batch_create(
         self, 
-        input_object: Optional[Type[BaseResource]] = None,
+        input_object: Optional[BaseResource] = None,
         return_response: bool = False,
         **kwargs
     ):
@@ -502,7 +503,7 @@ class BaseRoute(BaseModel):
 
     async def async_batch_create(
         self, 
-        input_object: Optional[Type[BaseResource]] = None,
+        input_object: Optional[BaseResource] = None,
         return_response: bool = False,
         **kwargs
     ):
@@ -537,7 +538,7 @@ class BaseRoute(BaseModel):
 
     def update(
         self, 
-        input_object: Optional[Type[BaseResource]] = None,
+        input_object: Optional[BaseResource] = None,
         resource_id: str = None,
         **kwargs
     ):
@@ -575,7 +576,7 @@ class BaseRoute(BaseModel):
 
     async def async_update(
         self, 
-        input_object: Optional[Type[BaseResource]] = None,
+        input_object: Optional[BaseResource] = None,
         resource_id: str = None,
         **kwargs
     ):
@@ -649,7 +650,7 @@ class BaseRoute(BaseModel):
     def upsert(
         self,
         resource_id: str,
-        input_object: Optional[Type[BaseResource]] = None,
+        input_object: Optional[BaseResource] = None,
         update_existing: bool = False, 
         overwrite_existing: bool = False,
         **kwargs
@@ -679,7 +680,7 @@ class BaseRoute(BaseModel):
     async def async_upsert(
         self,
         resource_id: str,
-        input_object: Optional[Type[BaseResource]] = None,
+        input_object: Optional[BaseResource] = None,
         update_existing: bool = False, 
         overwrite_existing: bool = False,
         **kwargs
@@ -810,7 +811,7 @@ class BaseRoute(BaseModel):
         data: Dict,
         response_object: Optional[Type[BaseResource]] = None,
         **kwargs
-    ):
+    ) -> BaseResource:
         """
         Prepare the Response Object
         
